bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOMoments.get_converter
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOMoments.get_converter